****************************************************************************
* Program:  scale.prg
*        :  (c) 1991 Charlie Thompson - CompuServe ID:  72740,346
*        :
* Purpose:  "cut & paste" source file for musical pitches
*  Syntax:  ? scale()
* Returns:  nothing (nul string)
*   Notes:  This file produces the musical range of the piano using FoxPro's
*        :  enhanced SET BELL command.  The frequency table was copied from
*        :  an electonics book which unfortunately didn't include sharps.
*        :  If you want to experiment, the frequency for a sharp is slightly
*        :  below the 1/2 way poin between it's adjoining naturals.  FoxPro
*        :  truncates decimals in the frequency parameter, rather than 
*        :  rounding them, so for best intonation use rounded integers.
*        :  Below is the easiest method I've found for writing FoxTunes.
*        :    1.  Block copy the range of needed pitches new file.
*        :    2.  In the new file, move and/or clone the pitches as needed.
*        :    3.  After the notes are all in place, change the durations as 
*        :        needed for rhythm.
*        :    4.  It's easiest to use a variable for the duration parameter.
*        :        Initialize "dur" as the most common note duration, then
*        :        reference other values as "dur * N" or "dur /N", ie:
*        :           dur = 4   && assuming 4 is a quarter note
*        :           dur * 1.5 && = dotted quarter
*        :           dur * 2   && = half note
*        :           dur / 2   && = half note, etc.
*        :        By doing it this way, the initial value for "dur" may be
*        :        be used as a rough tempo control.  "dur" formulas must
*        :        evaluate to integers from 1 to 19, to avoid syntax errors.
*        :  I wrote this using FoxPro 2.0, but it should also work with 
*        :  version 1.  Enjoy!
****************************************************************************
dur = 8  && Change this to a value from 1 to 19 to vary tempo.
***************************************************************************
* The lowest notes are almost pitchless.  The first 2 octaves will also   *
* produce a predominant 1st overtone (octave above) on a PC speaker.  The * 
* The lower portion of the scale is a bit out-of-tune due to the limited  *
* resolution (integers only) of the SET BELL command                      *
***************************************************************************
SET BELL TO 28, dur  && A1 (lowest A on piano)
?? CHR(7)
SET BELL TO 31, dur  && B1
?? CHR(7)
SET BELL TO 33, dur  && C1
?? CHR(7)
SET BELL TO 37, dur  && D1
?? CHR(7)
SET BELL TO 41, dur  && E1
?? CHR(7)
SET BELL TO 44, dur  && F1
?? CHR(7)
SET BELL TO 49, dur  && G1
?? CHR(7)
SET BELL TO 55, dur  &&  A2
?? CHR(7)
SET BELL TO 62, dur  && B2
?? CHR(7)
SET BELL TO 65, dur  && C2
?? CHR(7)
SET BELL TO 73, dur  && D2
?? CHR(7)
SET BELL TO 82, dur  && E2
?? CHR(7)
SET BELL TO 87, dur  && F2
?? CHR(7)
SET BELL TO 98, dur  && G2
?? CHR(7)
*************************************************************
* Frequencies most likely to be musically useful start here *
*************************************************************
SET BELL TO 110, dur  && A3
?? CHR(7)
SET BELL TO 123, dur  && B3
?? CHR(7)
SET BELL TO 131, dur  && C3
?? CHR(7)
SET BELL TO 147, dur  && D3
?? CHR(7)
SET BELL TO 165, dur  && E3
?? CHR(7)
SET BELL TO 175, dur  && F3
?? CHR(7)
SET BELL TO 196, dur  && G3
?? CHR(7)
SET BELL TO 220, dur  && A4
?? CHR(7)
SET BELL TO 247, dur  && B4
?? CHR(7)
SET BELL TO 262, dur  && C4 (middle C)
?? CHR(7)
SET BELL TO 294, dur  && D4
?? CHR(7)
SET BELL TO 330, dur  && E4
?? CHR(7)
SET BELL TO 349, dur  && F4
?? CHR(7)
SET BELL TO 392, dur  && G4
?? CHR(7)
SET BELL TO 440, dur  && A5
?? CHR(7)
SET BELL TO 494, dur  && B5
?? CHR(7)
SET BELL TO 523, dur  && C5
?? CHR(7)
SET BELL TO 587, dur  && D5
?? CHR(7)
SET BELL TO 659, dur  && E5
?? CHR(7)
SET BELL TO 699, dur  && F5
?? CHR(7)
SET BELL TO 784, dur  && G5
?? CHR(7)
SET BELL TO 880, dur  && A6
?? CHR(7)
SET BELL TO 988, dur  && B6
?? CHR(7)
SET BELL TO 1047, dur  && C6
?? CHR(7)
***********************************************************
* Frequencies most likely to be musically useful end here *
***********************************************************
SET BELL TO 1175, dur  && D6
?? CHR(7)
SET BELL TO 1319, dur  && E6
?? CHR(7)
SET BELL TO 1397, dur  && F6
?? CHR(7)
SET BELL TO 1568, dur  && G6
?? CHR(7)
SET BELL TO 1760, dur  && A7
?? CHR(7)
SET BELL TO 1975, dur  && B7
?? CHR(7)
*************************************************************************
* Frequencies beyond this point are pretty squeaky.  Perhaps useful for *
* for those extra annoying special effects!                             *
*************************************************************************
SET BELL TO 2093, dur  && C7
?? CHR(7)
SET BELL TO 2349, dur  && D7
?? CHR(7)
SET BELL TO 2637, dur  && E7
?? CHR(7)
SET BELL TO 2794, dur  && F7
?? CHR(7)
SET BELL TO 3136, dur  && G7
?? CHR(7)
SET BELL TO 3520, dur  && A8
?? CHR(7)
SET BELL TO 3951, dur  && B8
?? CHR(7)
SET BELL TO 4186, dur  && C8 (highest C on piano)
?? CHR(7)
SET BELL TO
RETURN ""

****************************************************************************
* Here's a few sharps I figured out manually                               *
****************************************************************************
SET BELL TO 278, dur   && C#4 
?? CHR(7)
SET BELL TO 312, dur   && D#4
?? CHR(7)
SET BELL TO 370, dur   && F#4
?? CHR(7)
SET BELL TO 416, dur   && A#5
?? CHR(7)
SET BELL TO 555, dur   && C#5
?? CHR(7)
